.. _ tochamber:

to the chamber
==============

Geachte heer Thate,

Uw reactie zal worden aangeboden aan de leden van de vaste commissies voor VWS en J&V.

Met vriendelijke groet,


Warmolt DE BOER

| Griffier van de commissies:
| -  Economische Zaken en Klimaat / Landbouw, Natuur en Voedselkwaliteit (EZK/LNV) 
| -  Infrastructuur, Waterstaat en Omgeving (IWO)  
| -  Volksgezondheid, Welzijn en Sport (VWS) 
| _____________________________________________ 
| Eerste Kamer der Staten-Generaal
| Binnenhof 22
| Postbus 20017
| 2500 EA Den Haag 
| M +31 (0)6 15619163
| E  warmolt.deboer@eerstekamer.nl
| I   www.eerstekamer.nl 


| -----Oorspronkelijk bericht-----
| Van: Bart Thate [mailto:bthate@dds.nl] 
| Verzonden: woensdag 22 november 2017 12:40
| Aan: EK-postbus
| CC: EK-postbus; Aardema, M. (Max); Apeldoorn, Dr. E.B. (Bastiaan) van; Forw.bijs2008; Atsma, J.J. (Joop); Bikker, M.H. (Mirjam); A.L.Bredenoord@umcutrecht.nl; Bredenoord, dr. A.L. (Annelien); timmerman@eerstekamer.nl; joris@jorisbacker.nl; Beuving, mr.dr. J. (Jannette); brinkman.Elco@gmail.com; thuis; Voorzitter Eerste Kamer; forw.bruj0702; Bruijn-Wezeman, R.G. (Reina) de; Engels, prof.mr. J.W.M. (Hans); Dercksen, R.G.J. (René); Dijk van D.J.H. (eerstekamer); Don, drs. H.M. (Hans-Martin); a.w.duthler@duthler.nl; Flierman, dr. A.H. (Anne); forw.GANR1402; Ganzevoort, Prof.dr. R.R. (Ruard); Gerkens, A.M.V. (Arda); Graaf, T.C. (Thom) de; Hattem, A.W.J.A. (Alexander) van; a.j.m.van.kesteren@ps-provinciegroningen.nl; hendrik@tenhoeve.frl; Hoeve, drs. H. (Henk) ten; Kesteren, A.J.M. (Ton) van; Kesteren, mr. N.J.J. (Niek Jan) van; schiedon@eerstekamer.nl; ajorritsma@denijestins.nl; Jorritsma-Lebbink, A. (Annemarie); fevankappen317@me.com; Klip-Martin, drs. T. (Tanja); Knapen, dr. H.P.M. (Ben); aobo78jq@kpnmail.nl; Köhler, F. (Frank); Kok, mr. C.J. (Kees); Forw.koxm0605; Nagel, J.G. (Jan); Kuiper, prof. dr. R. (Roel); frits.lintmeijer@me.com; Lintmeijer, drs. F.C.W.C. (Frits); Lokin-Sassen, mr. P.E.M.S. (Pia); Martens, drs. M.J.T. (Maria); mmeijer@sp.nl; Meijer, M.P. (Meta); Nooren, drs. J.E.A.M. (Jopie); Overbeek, Prof. dr. H.W (Henk); henkpijlman@gmail.com; postemaprive@gmail.com; "a.postema@eerstekamer.nl hmprast"@gmail.com; Prast, prof.dr. H.M. (Henriëtte); marnix.van.rij@nl.ey.com; Rij, M.L.A. (Marnix) van; ahgrinnooykan@hotmail.com; a.h.g.rinnooykan@uva.nl; Rinnooy Kan, prof.dr. A.H.G. (Alexander); Rombouts, mr.dr. A.G.J.M. (Ton); b.ruers@sp.nl; S.Schaap@tip.nl; Schalk, P. (Peter); hermanschaper65@yahoo.com; Schaper, drs. H.A. (Herman); Schnabel, prof.dr. P. (Paul); Schouwenaar, mr. J.M. (Koos); Sent, Prof.dr. E.M. (Esther Mirjam); Sini, M. (Mohamed); Sluijs, D.J. (Dannij) van der; Stienen, drs. C.P.W.J. (Petra); Strien, ir.drs. G.A. (Gom) van; Strik, mr. dr. M.H.A. (Tineke); Teunissen, C. (Christine); Ven, M.P.M. (Mart) van de; Verheijen, drs. L.H.J. (Lambert); Vlietstra, J.G. (Janny); "Email: marijkevos"@xs4all.nl; leggedoor@eerstekamer.nl; Wezel, mr. A.M.T. (Anneke); Bergman, F.J. (Fred); Boer, mr. W. (Warmolt) de; Dooren, mr. W.A.J.M. (Kim) van; Griffier Eerste Kamer; Luijk, drs. R.H. (Luuk) van; Prins, R.M. (René); Westerhoff A.
| Onderwerp: bewijs dat antipsychotica gif zijn

     Geachte leden van de Eerste Kamer der Staten-Generaal,

ik schrijf u om u te informeren dat de medicatie genoemd in de Wet verplichte GGZ in de praktijk ook het toedienen van gif omvat.

Er is bewijs dat antipsychotica gif zijn:

| haloperiodol (haldol) - https://echa.europa.eu/substance-information/-/substanceinfo/100.000.142
| clozapine (leponex) - https://echa.europa.eu/substance-information/-/substanceinfo/100.024.831
| olanzapine (zyprexa) - https://echa.europa.eu/substance-information/-/substanceinfo/100.125.320
| aripriprazole (abilify) - https://echa.europa.eu/substance-information/-/substanceinfo/100.112.53

Uw wettelijk voorschrift word gebruikt voor het toedienen van gif wat strafbaar is als u met de Wet verplichte GGZ straffeloosheid verschaft,

Straffeloosheid verschaffen (verzekeren) is strafbaar met levenlang.

Ik  hoop dat u deze wet zult heroverwegen en de toedieningen van gif verder laat onderzoeken,

Hoogachtend,


Bart Thate
Heerhugowaard
22-10-2017
